@@ -33,12 +33,13 @@ int getTxChar();
 void insert(int);
 void insert(QString,int);
 void clear();
+bool isEmpty();
 
 private:
 int txbuffer[TXBUFFER_LENGTH];
 int filled;
-unsigned int inpos;
-unsigned int outpos;
+int inpos;
+int outpos;
 };
 
 #endif
