@@ -16,16 +16,32 @@
 
 #include "input.h"
 #include <errno.h>
-Input::Input(int ptt)
+Input::Input ( int ptt ) : QThread()
 {
-serial=ptt;
+  serial = ptt;
 }
 Input::~Input()
 {
 }
+void Input::run()
+{
+  started = true;
+  while ( started )
+  {
+    msleep ( 300 );
+    emit samplesAvailable();
+  }
+}
+void Input::stop()
+{
+  started = false;
+}
+
+
+
+
 
 
 
 
-	
 
